@@ -51,7 +51,7 @@ trans_func <- R6Class(classname = "trans_func",
 		#'
 		#' @param prok_database default "FAPROTAX"; \code{"FAPROTAX"} or \code{"NJC19"}; select a prokaryotic trait database:
 		#'   \describe{
-		#'     \item{\strong{'FAPROTAX'}}{FAPROTAX v1.2.4; Reference: Louca et al. (2016). Decoupling function and taxonomy in the global ocean microbiome. 
+		#'     \item{\strong{'FAPROTAX'}}{FAPROTAX; Reference: Louca et al. (2016). Decoupling function and taxonomy in the global ocean microbiome. 
 		#'     	  Science, 353(6305), 1272. <doi:10.1126/science.aaf4507>}
 		#'     \item{\strong{'NJC19'}}{NJC19: Lim et al. (2020). Large-scale metabolic interaction network of the mouse and human gut microbiota. 
 		#'     	  Scientific Data, 7(1). <10.1038/s41597-020-0516-5>. 
@@ -89,7 +89,7 @@ trans_func <- R6Class(classname = "trans_func",
 					# Copyright (c) 2023, Stilianos Louca. All rights reserved.
 					# developed based on the FAPROTAX database (http://www.loucalab.com/archive/FAPROTAX/lib/php/index.php?section=Home)
 					data("prok_func_FAPROTAX", envir = environment())
-					message("FAPROTAX v1.2.6. Please also cite the original FAPROTAX paper: Louca et al. (2016).")
+					message("FAPROTAX v", prok_func_FAPROTAX$ver, ". Please also cite the original FAPROTAX paper: Louca et al. (2016).")
 					message("Decoupling function and taxonomy in the global ocean microbiome. Science, 353(6305), 1272.\n")
 					# collapse taxonomy
 					tax1 <- apply(tax1, 1, function(x){paste0(x, collapse = ";")}) %>% 
